mcptool

package
v0.0.0-...-a92bd8c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: AGPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the mcptool type in the database.
	Label = "mcp_tool"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldUpstreamID holds the string denoting the upstream_id field in the database.
	FieldUpstreamID = "upstream_id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldNamespacedName holds the string denoting the namespaced_name field in the database.
	FieldNamespacedName = "namespaced_name"
	// FieldScope holds the string denoting the scope field in the database.
	FieldScope = "scope"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// FieldDescription holds the string denoting the description field in the database.
	FieldDescription = "description"
	// FieldInputSchema holds the string denoting the input_schema field in the database.
	FieldInputSchema = "input_schema"
	// FieldPrice holds the string denoting the price field in the database.
	FieldPrice = "price"
	// FieldEnabled holds the string denoting the enabled field in the database.
	FieldEnabled = "enabled"
	// FieldVersionHash holds the string denoting the version_hash field in the database.
	FieldVersionHash = "version_hash"
	// FieldSyncedAt holds the string denoting the synced_at field in the database.
	FieldSyncedAt = "synced_at"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// EdgeUpstream holds the string denoting the upstream edge name in mutations.
	EdgeUpstream = "upstream"
	// Table holds the table name of the mcptool in the database.
	Table = "mcp_tools"
	// UpstreamTable is the table that holds the upstream relation/edge.
	UpstreamTable = "mcp_tools"
	// UpstreamInverseTable is the table name for the MCPUpstream entity.
	// It exists in this package in order to avoid circular dependency with the "mcpupstream" package.
	UpstreamInverseTable = "mcp_upstreams"
	// UpstreamColumn is the table column denoting the upstream relation/edge.
	UpstreamColumn = "upstream_id"
)

Variables

var (
	Hooks        [1]ent.Hook
	Interceptors [1]ent.Interceptor
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// NamespacedNameValidator is a validator for the "namespaced_name" field. It is called by the builders before save.
	NamespacedNameValidator func(string) error
	// DefaultPrice holds the default value on creation for the "price" field.
	DefaultPrice int64
	// DefaultEnabled holds the default value on creation for the "enabled" field.
	DefaultEnabled bool
	// VersionHashValidator is a validator for the "version_hash" field. It is called by the builders before save.
	VersionHashValidator func(string) error
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/chaitin/MonkeyCode/backend/db/runtime"

Columns holds all SQL columns for mcptool fields.

Functions

func And

func And(predicates ...predicate.MCPTool) predicate.MCPTool

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.MCPTool

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.MCPTool

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.MCPTool

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.MCPTool

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.MCPTool

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.MCPTool

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.MCPTool

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.MCPTool

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.MCPTool

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.MCPTool

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.MCPTool

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.MCPTool

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.MCPTool

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.MCPTool

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.MCPTool

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.MCPTool

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.MCPTool

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.MCPTool

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.MCPTool

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.MCPTool

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func Description

func Description(v string) predicate.MCPTool

Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.

func DescriptionContains

func DescriptionContains(v string) predicate.MCPTool

DescriptionContains applies the Contains predicate on the "description" field.

func DescriptionContainsFold

func DescriptionContainsFold(v string) predicate.MCPTool

DescriptionContainsFold applies the ContainsFold predicate on the "description" field.

func DescriptionEQ

func DescriptionEQ(v string) predicate.MCPTool

DescriptionEQ applies the EQ predicate on the "description" field.

func DescriptionEqualFold

func DescriptionEqualFold(v string) predicate.MCPTool

DescriptionEqualFold applies the EqualFold predicate on the "description" field.

func DescriptionGT

func DescriptionGT(v string) predicate.MCPTool

DescriptionGT applies the GT predicate on the "description" field.

func DescriptionGTE

func DescriptionGTE(v string) predicate.MCPTool

DescriptionGTE applies the GTE predicate on the "description" field.

func DescriptionHasPrefix

func DescriptionHasPrefix(v string) predicate.MCPTool

DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.

func DescriptionHasSuffix

func DescriptionHasSuffix(v string) predicate.MCPTool

DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.

func DescriptionIn

func DescriptionIn(vs ...string) predicate.MCPTool

DescriptionIn applies the In predicate on the "description" field.

func DescriptionIsNil

func DescriptionIsNil() predicate.MCPTool

DescriptionIsNil applies the IsNil predicate on the "description" field.

func DescriptionLT

func DescriptionLT(v string) predicate.MCPTool

DescriptionLT applies the LT predicate on the "description" field.

func DescriptionLTE

func DescriptionLTE(v string) predicate.MCPTool

DescriptionLTE applies the LTE predicate on the "description" field.

func DescriptionNEQ

func DescriptionNEQ(v string) predicate.MCPTool

DescriptionNEQ applies the NEQ predicate on the "description" field.

func DescriptionNotIn

func DescriptionNotIn(vs ...string) predicate.MCPTool

DescriptionNotIn applies the NotIn predicate on the "description" field.

func DescriptionNotNil

func DescriptionNotNil() predicate.MCPTool

DescriptionNotNil applies the NotNil predicate on the "description" field.

func Enabled

func Enabled(v bool) predicate.MCPTool

Enabled applies equality check predicate on the "enabled" field. It's identical to EnabledEQ.

func EnabledEQ

func EnabledEQ(v bool) predicate.MCPTool

EnabledEQ applies the EQ predicate on the "enabled" field.

func EnabledNEQ

func EnabledNEQ(v bool) predicate.MCPTool

EnabledNEQ applies the NEQ predicate on the "enabled" field.

func HasUpstream

func HasUpstream() predicate.MCPTool

HasUpstream applies the HasEdge predicate on the "upstream" edge.

func HasUpstreamWith

func HasUpstreamWith(preds ...predicate.MCPUpstream) predicate.MCPTool

HasUpstreamWith applies the HasEdge predicate on the "upstream" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.MCPTool

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.MCPTool

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.MCPTool

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.MCPTool

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.MCPTool

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.MCPTool

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.MCPTool

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.MCPTool

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.MCPTool

IDNotIn applies the NotIn predicate on the ID field.

func InputSchemaIsNil

func InputSchemaIsNil() predicate.MCPTool

InputSchemaIsNil applies the IsNil predicate on the "input_schema" field.

func InputSchemaNotNil

func InputSchemaNotNil() predicate.MCPTool

InputSchemaNotNil applies the NotNil predicate on the "input_schema" field.

func Name

func Name(v string) predicate.MCPTool

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.MCPTool

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.MCPTool

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.MCPTool

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.MCPTool

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.MCPTool

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.MCPTool

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.MCPTool

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.MCPTool

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.MCPTool

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.MCPTool

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.MCPTool

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.MCPTool

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.MCPTool

NameNotIn applies the NotIn predicate on the "name" field.

func NamespacedName

func NamespacedName(v string) predicate.MCPTool

NamespacedName applies equality check predicate on the "namespaced_name" field. It's identical to NamespacedNameEQ.

func NamespacedNameContains

func NamespacedNameContains(v string) predicate.MCPTool

NamespacedNameContains applies the Contains predicate on the "namespaced_name" field.

func NamespacedNameContainsFold

func NamespacedNameContainsFold(v string) predicate.MCPTool

NamespacedNameContainsFold applies the ContainsFold predicate on the "namespaced_name" field.

func NamespacedNameEQ

func NamespacedNameEQ(v string) predicate.MCPTool

NamespacedNameEQ applies the EQ predicate on the "namespaced_name" field.

func NamespacedNameEqualFold

func NamespacedNameEqualFold(v string) predicate.MCPTool

NamespacedNameEqualFold applies the EqualFold predicate on the "namespaced_name" field.

func NamespacedNameGT

func NamespacedNameGT(v string) predicate.MCPTool

NamespacedNameGT applies the GT predicate on the "namespaced_name" field.

func NamespacedNameGTE

func NamespacedNameGTE(v string) predicate.MCPTool

NamespacedNameGTE applies the GTE predicate on the "namespaced_name" field.

func NamespacedNameHasPrefix

func NamespacedNameHasPrefix(v string) predicate.MCPTool

NamespacedNameHasPrefix applies the HasPrefix predicate on the "namespaced_name" field.

func NamespacedNameHasSuffix

func NamespacedNameHasSuffix(v string) predicate.MCPTool

NamespacedNameHasSuffix applies the HasSuffix predicate on the "namespaced_name" field.

func NamespacedNameIn

func NamespacedNameIn(vs ...string) predicate.MCPTool

NamespacedNameIn applies the In predicate on the "namespaced_name" field.

func NamespacedNameLT

func NamespacedNameLT(v string) predicate.MCPTool

NamespacedNameLT applies the LT predicate on the "namespaced_name" field.

func NamespacedNameLTE

func NamespacedNameLTE(v string) predicate.MCPTool

NamespacedNameLTE applies the LTE predicate on the "namespaced_name" field.

func NamespacedNameNEQ

func NamespacedNameNEQ(v string) predicate.MCPTool

NamespacedNameNEQ applies the NEQ predicate on the "namespaced_name" field.

func NamespacedNameNotIn

func NamespacedNameNotIn(vs ...string) predicate.MCPTool

NamespacedNameNotIn applies the NotIn predicate on the "namespaced_name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.MCPTool) predicate.MCPTool

Or groups predicates with the OR operator between them.

func Price

func Price(v int64) predicate.MCPTool

Price applies equality check predicate on the "price" field. It's identical to PriceEQ.

func PriceEQ

func PriceEQ(v int64) predicate.MCPTool

PriceEQ applies the EQ predicate on the "price" field.

func PriceGT

func PriceGT(v int64) predicate.MCPTool

PriceGT applies the GT predicate on the "price" field.

func PriceGTE

func PriceGTE(v int64) predicate.MCPTool

PriceGTE applies the GTE predicate on the "price" field.

func PriceIn

func PriceIn(vs ...int64) predicate.MCPTool

PriceIn applies the In predicate on the "price" field.

func PriceLT

func PriceLT(v int64) predicate.MCPTool

PriceLT applies the LT predicate on the "price" field.

func PriceLTE

func PriceLTE(v int64) predicate.MCPTool

PriceLTE applies the LTE predicate on the "price" field.

func PriceNEQ

func PriceNEQ(v int64) predicate.MCPTool

PriceNEQ applies the NEQ predicate on the "price" field.

func PriceNotIn

func PriceNotIn(vs ...int64) predicate.MCPTool

PriceNotIn applies the NotIn predicate on the "price" field.

func ScopeEQ

func ScopeEQ(v Scope) predicate.MCPTool

ScopeEQ applies the EQ predicate on the "scope" field.

func ScopeIn

func ScopeIn(vs ...Scope) predicate.MCPTool

ScopeIn applies the In predicate on the "scope" field.

func ScopeNEQ

func ScopeNEQ(v Scope) predicate.MCPTool

ScopeNEQ applies the NEQ predicate on the "scope" field.

func ScopeNotIn

func ScopeNotIn(vs ...Scope) predicate.MCPTool

ScopeNotIn applies the NotIn predicate on the "scope" field.

func ScopeValidator

func ScopeValidator(s Scope) error

ScopeValidator is a validator for the "scope" field enum values. It is called by the builders before save.

func SyncedAt

func SyncedAt(v time.Time) predicate.MCPTool

SyncedAt applies equality check predicate on the "synced_at" field. It's identical to SyncedAtEQ.

func SyncedAtEQ

func SyncedAtEQ(v time.Time) predicate.MCPTool

SyncedAtEQ applies the EQ predicate on the "synced_at" field.

func SyncedAtGT

func SyncedAtGT(v time.Time) predicate.MCPTool

SyncedAtGT applies the GT predicate on the "synced_at" field.

func SyncedAtGTE

func SyncedAtGTE(v time.Time) predicate.MCPTool

SyncedAtGTE applies the GTE predicate on the "synced_at" field.

func SyncedAtIn

func SyncedAtIn(vs ...time.Time) predicate.MCPTool

SyncedAtIn applies the In predicate on the "synced_at" field.

func SyncedAtIsNil

func SyncedAtIsNil() predicate.MCPTool

SyncedAtIsNil applies the IsNil predicate on the "synced_at" field.

func SyncedAtLT

func SyncedAtLT(v time.Time) predicate.MCPTool

SyncedAtLT applies the LT predicate on the "synced_at" field.

func SyncedAtLTE

func SyncedAtLTE(v time.Time) predicate.MCPTool

SyncedAtLTE applies the LTE predicate on the "synced_at" field.

func SyncedAtNEQ

func SyncedAtNEQ(v time.Time) predicate.MCPTool

SyncedAtNEQ applies the NEQ predicate on the "synced_at" field.

func SyncedAtNotIn

func SyncedAtNotIn(vs ...time.Time) predicate.MCPTool

SyncedAtNotIn applies the NotIn predicate on the "synced_at" field.

func SyncedAtNotNil

func SyncedAtNotNil() predicate.MCPTool

SyncedAtNotNil applies the NotNil predicate on the "synced_at" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.MCPTool

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.MCPTool

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.MCPTool

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.MCPTool

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.MCPTool

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.MCPTool

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.MCPTool

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.MCPTool

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.MCPTool

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpstreamID

func UpstreamID(v uuid.UUID) predicate.MCPTool

UpstreamID applies equality check predicate on the "upstream_id" field. It's identical to UpstreamIDEQ.

func UpstreamIDEQ

func UpstreamIDEQ(v uuid.UUID) predicate.MCPTool

UpstreamIDEQ applies the EQ predicate on the "upstream_id" field.

func UpstreamIDIn

func UpstreamIDIn(vs ...uuid.UUID) predicate.MCPTool

UpstreamIDIn applies the In predicate on the "upstream_id" field.

func UpstreamIDNEQ

func UpstreamIDNEQ(v uuid.UUID) predicate.MCPTool

UpstreamIDNEQ applies the NEQ predicate on the "upstream_id" field.

func UpstreamIDNotIn

func UpstreamIDNotIn(vs ...uuid.UUID) predicate.MCPTool

UpstreamIDNotIn applies the NotIn predicate on the "upstream_id" field.

func UserID

func UserID(v uuid.UUID) predicate.MCPTool

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

func UserIDEQ(v uuid.UUID) predicate.MCPTool

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDGT

func UserIDGT(v uuid.UUID) predicate.MCPTool

UserIDGT applies the GT predicate on the "user_id" field.

func UserIDGTE

func UserIDGTE(v uuid.UUID) predicate.MCPTool

UserIDGTE applies the GTE predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...uuid.UUID) predicate.MCPTool

UserIDIn applies the In predicate on the "user_id" field.

func UserIDIsNil

func UserIDIsNil() predicate.MCPTool

UserIDIsNil applies the IsNil predicate on the "user_id" field.

func UserIDLT

func UserIDLT(v uuid.UUID) predicate.MCPTool

UserIDLT applies the LT predicate on the "user_id" field.

func UserIDLTE

func UserIDLTE(v uuid.UUID) predicate.MCPTool

UserIDLTE applies the LTE predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v uuid.UUID) predicate.MCPTool

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...uuid.UUID) predicate.MCPTool

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func UserIDNotNil

func UserIDNotNil() predicate.MCPTool

UserIDNotNil applies the NotNil predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func VersionHash

func VersionHash(v string) predicate.MCPTool

VersionHash applies equality check predicate on the "version_hash" field. It's identical to VersionHashEQ.

func VersionHashContains

func VersionHashContains(v string) predicate.MCPTool

VersionHashContains applies the Contains predicate on the "version_hash" field.

func VersionHashContainsFold

func VersionHashContainsFold(v string) predicate.MCPTool

VersionHashContainsFold applies the ContainsFold predicate on the "version_hash" field.

func VersionHashEQ

func VersionHashEQ(v string) predicate.MCPTool

VersionHashEQ applies the EQ predicate on the "version_hash" field.

func VersionHashEqualFold

func VersionHashEqualFold(v string) predicate.MCPTool

VersionHashEqualFold applies the EqualFold predicate on the "version_hash" field.

func VersionHashGT

func VersionHashGT(v string) predicate.MCPTool

VersionHashGT applies the GT predicate on the "version_hash" field.

func VersionHashGTE

func VersionHashGTE(v string) predicate.MCPTool

VersionHashGTE applies the GTE predicate on the "version_hash" field.

func VersionHashHasPrefix

func VersionHashHasPrefix(v string) predicate.MCPTool

VersionHashHasPrefix applies the HasPrefix predicate on the "version_hash" field.

func VersionHashHasSuffix

func VersionHashHasSuffix(v string) predicate.MCPTool

VersionHashHasSuffix applies the HasSuffix predicate on the "version_hash" field.

func VersionHashIn

func VersionHashIn(vs ...string) predicate.MCPTool

VersionHashIn applies the In predicate on the "version_hash" field.

func VersionHashIsNil

func VersionHashIsNil() predicate.MCPTool

VersionHashIsNil applies the IsNil predicate on the "version_hash" field.

func VersionHashLT

func VersionHashLT(v string) predicate.MCPTool

VersionHashLT applies the LT predicate on the "version_hash" field.

func VersionHashLTE

func VersionHashLTE(v string) predicate.MCPTool

VersionHashLTE applies the LTE predicate on the "version_hash" field.

func VersionHashNEQ

func VersionHashNEQ(v string) predicate.MCPTool

VersionHashNEQ applies the NEQ predicate on the "version_hash" field.

func VersionHashNotIn

func VersionHashNotIn(vs ...string) predicate.MCPTool

VersionHashNotIn applies the NotIn predicate on the "version_hash" field.

func VersionHashNotNil

func VersionHashNotNil() predicate.MCPTool

VersionHashNotNil applies the NotNil predicate on the "version_hash" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the MCPTool queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDescription

func ByDescription(opts ...sql.OrderTermOption) OrderOption

ByDescription orders the results by the description field.

func ByEnabled

func ByEnabled(opts ...sql.OrderTermOption) OrderOption

ByEnabled orders the results by the enabled field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByNamespacedName

func ByNamespacedName(opts ...sql.OrderTermOption) OrderOption

ByNamespacedName orders the results by the namespaced_name field.

func ByPrice

func ByPrice(opts ...sql.OrderTermOption) OrderOption

ByPrice orders the results by the price field.

func ByScope

func ByScope(opts ...sql.OrderTermOption) OrderOption

ByScope orders the results by the scope field.

func BySyncedAt

func BySyncedAt(opts ...sql.OrderTermOption) OrderOption

BySyncedAt orders the results by the synced_at field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpstreamField

func ByUpstreamField(field string, opts ...sql.OrderTermOption) OrderOption

ByUpstreamField orders the results by upstream field.

func ByUpstreamID

func ByUpstreamID(opts ...sql.OrderTermOption) OrderOption

ByUpstreamID orders the results by the upstream_id field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

func ByVersionHash

func ByVersionHash(opts ...sql.OrderTermOption) OrderOption

ByVersionHash orders the results by the version_hash field.

type Scope

type Scope string

Scope defines the type for the "scope" enum field.

const (
	ScopeUser     Scope = "user"
	ScopePlatform Scope = "platform"
)

Scope values.

func (Scope) String

func (s Scope) String() string

Jump to