mcpusertoolsetting

package
v0.0.0-...-5f31c4b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the mcpusertoolsetting type in the database.
	Label = "mcp_user_tool_setting"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// FieldToolID holds the string denoting the tool_id field in the database.
	FieldToolID = "tool_id"
	// FieldEnabled holds the string denoting the enabled field in the database.
	FieldEnabled = "enabled"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// Table holds the table name of the mcpusertoolsetting in the database.
	Table = "mcp_user_tool_settings"
)

Variables

var (
	// DefaultEnabled holds the default value on creation for the "enabled" field.
	DefaultEnabled bool
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
)

Columns holds all SQL columns for mcpusertoolsetting fields.

Functions

func And

And groups predicates with the AND operator between them.

func CreatedAt

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.MCPUserToolSetting

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.MCPUserToolSetting

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.MCPUserToolSetting

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.MCPUserToolSetting

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.MCPUserToolSetting

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.MCPUserToolSetting

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.MCPUserToolSetting

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.MCPUserToolSetting

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func Enabled

Enabled applies equality check predicate on the "enabled" field. It's identical to EnabledEQ.

func EnabledEQ

func EnabledEQ(v bool) predicate.MCPUserToolSetting

EnabledEQ applies the EQ predicate on the "enabled" field.

func EnabledNEQ

func EnabledNEQ(v bool) predicate.MCPUserToolSetting

EnabledNEQ applies the NEQ predicate on the "enabled" field.

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.MCPUserToolSetting

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func ToolID

ToolID applies equality check predicate on the "tool_id" field. It's identical to ToolIDEQ.

func ToolIDEQ

ToolIDEQ applies the EQ predicate on the "tool_id" field.

func ToolIDGT

ToolIDGT applies the GT predicate on the "tool_id" field.

func ToolIDGTE

ToolIDGTE applies the GTE predicate on the "tool_id" field.

func ToolIDIn

func ToolIDIn(vs ...uuid.UUID) predicate.MCPUserToolSetting

ToolIDIn applies the In predicate on the "tool_id" field.

func ToolIDLT

ToolIDLT applies the LT predicate on the "tool_id" field.

func ToolIDLTE

ToolIDLTE applies the LTE predicate on the "tool_id" field.

func ToolIDNEQ

ToolIDNEQ applies the NEQ predicate on the "tool_id" field.

func ToolIDNotIn

func ToolIDNotIn(vs ...uuid.UUID) predicate.MCPUserToolSetting

ToolIDNotIn applies the NotIn predicate on the "tool_id" field.

func UpdatedAt

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.MCPUserToolSetting

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.MCPUserToolSetting

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.MCPUserToolSetting

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.MCPUserToolSetting

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.MCPUserToolSetting

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.MCPUserToolSetting

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.MCPUserToolSetting

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.MCPUserToolSetting

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UserID

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDGT

UserIDGT applies the GT predicate on the "user_id" field.

func UserIDGTE

UserIDGTE applies the GTE predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...uuid.UUID) predicate.MCPUserToolSetting

UserIDIn applies the In predicate on the "user_id" field.

func UserIDLT

UserIDLT applies the LT predicate on the "user_id" field.

func UserIDLTE

UserIDLTE applies the LTE predicate on the "user_id" field.

func UserIDNEQ

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...uuid.UUID) predicate.MCPUserToolSetting

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the MCPUserToolSetting queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByEnabled

func ByEnabled(opts ...sql.OrderTermOption) OrderOption

ByEnabled orders the results by the enabled field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByToolID

func ByToolID(opts ...sql.OrderTermOption) OrderOption

ByToolID orders the results by the tool_id field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to