taskmodelswitch

package
v0.0.0-...-5f31c4b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the taskmodelswitch type in the database.
	Label = "task_model_switch"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldTaskID holds the string denoting the task_id field in the database.
	FieldTaskID = "task_id"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// FieldFromModelID holds the string denoting the from_model_id field in the database.
	FieldFromModelID = "from_model_id"
	// FieldToModelID holds the string denoting the to_model_id field in the database.
	FieldToModelID = "to_model_id"
	// FieldRequestID holds the string denoting the request_id field in the database.
	FieldRequestID = "request_id"
	// FieldLoadSession holds the string denoting the load_session field in the database.
	FieldLoadSession = "load_session"
	// FieldSuccess holds the string denoting the success field in the database.
	FieldSuccess = "success"
	// FieldMessage holds the string denoting the message field in the database.
	FieldMessage = "message"
	// FieldSessionID holds the string denoting the session_id field in the database.
	FieldSessionID = "session_id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// EdgeTask holds the string denoting the task edge name in mutations.
	EdgeTask = "task"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// EdgeFromModel holds the string denoting the from_model edge name in mutations.
	EdgeFromModel = "from_model"
	// EdgeToModel holds the string denoting the to_model edge name in mutations.
	EdgeToModel = "to_model"
	// Table holds the table name of the taskmodelswitch in the database.
	Table = "task_model_switches"
	// TaskTable is the table that holds the task relation/edge.
	TaskTable = "task_model_switches"
	// TaskInverseTable is the table name for the Task entity.
	// It exists in this package in order to avoid circular dependency with the "task" package.
	TaskInverseTable = "tasks"
	// TaskColumn is the table column denoting the task relation/edge.
	TaskColumn = "task_id"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "task_model_switches"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_id"
	// FromModelTable is the table that holds the from_model relation/edge.
	FromModelTable = "task_model_switches"
	// FromModelInverseTable is the table name for the Model entity.
	// It exists in this package in order to avoid circular dependency with the "model" package.
	FromModelInverseTable = "models"
	// FromModelColumn is the table column denoting the from_model relation/edge.
	FromModelColumn = "from_model_id"
	// ToModelTable is the table that holds the to_model relation/edge.
	ToModelTable = "task_model_switches"
	// ToModelInverseTable is the table name for the Model entity.
	// It exists in this package in order to avoid circular dependency with the "model" package.
	ToModelInverseTable = "models"
	// ToModelColumn is the table column denoting the to_model relation/edge.
	ToModelColumn = "to_model_id"
)

Variables

var (
	// DefaultRequestID holds the default value on creation for the "request_id" field.
	DefaultRequestID string
	// DefaultLoadSession holds the default value on creation for the "load_session" field.
	DefaultLoadSession bool
	// DefaultMessage holds the default value on creation for the "message" field.
	DefaultMessage string
	// DefaultSessionID holds the default value on creation for the "session_id" field.
	DefaultSessionID string
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for taskmodelswitch fields.

Functions

func And

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.TaskModelSwitch

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.TaskModelSwitch

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.TaskModelSwitch

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.TaskModelSwitch

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.TaskModelSwitch

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.TaskModelSwitch

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.TaskModelSwitch

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.TaskModelSwitch

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.TaskModelSwitch

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func FromModelID

func FromModelID(v uuid.UUID) predicate.TaskModelSwitch

FromModelID applies equality check predicate on the "from_model_id" field. It's identical to FromModelIDEQ.

func FromModelIDEQ

func FromModelIDEQ(v uuid.UUID) predicate.TaskModelSwitch

FromModelIDEQ applies the EQ predicate on the "from_model_id" field.

func FromModelIDIn

func FromModelIDIn(vs ...uuid.UUID) predicate.TaskModelSwitch

FromModelIDIn applies the In predicate on the "from_model_id" field.

func FromModelIDIsNil

func FromModelIDIsNil() predicate.TaskModelSwitch

FromModelIDIsNil applies the IsNil predicate on the "from_model_id" field.

func FromModelIDNEQ

func FromModelIDNEQ(v uuid.UUID) predicate.TaskModelSwitch

FromModelIDNEQ applies the NEQ predicate on the "from_model_id" field.

func FromModelIDNotIn

func FromModelIDNotIn(vs ...uuid.UUID) predicate.TaskModelSwitch

FromModelIDNotIn applies the NotIn predicate on the "from_model_id" field.

func FromModelIDNotNil

func FromModelIDNotNil() predicate.TaskModelSwitch

FromModelIDNotNil applies the NotNil predicate on the "from_model_id" field.

func HasFromModel

func HasFromModel() predicate.TaskModelSwitch

HasFromModel applies the HasEdge predicate on the "from_model" edge.

func HasFromModelWith

func HasFromModelWith(preds ...predicate.Model) predicate.TaskModelSwitch

HasFromModelWith applies the HasEdge predicate on the "from_model" edge with a given conditions (other predicates).

func HasTask

func HasTask() predicate.TaskModelSwitch

HasTask applies the HasEdge predicate on the "task" edge.

func HasTaskWith

func HasTaskWith(preds ...predicate.Task) predicate.TaskModelSwitch

HasTaskWith applies the HasEdge predicate on the "task" edge with a given conditions (other predicates).

func HasToModel

func HasToModel() predicate.TaskModelSwitch

HasToModel applies the HasEdge predicate on the "to_model" edge.

func HasToModelWith

func HasToModelWith(preds ...predicate.Model) predicate.TaskModelSwitch

HasToModelWith applies the HasEdge predicate on the "to_model" edge with a given conditions (other predicates).

func HasUser

func HasUser() predicate.TaskModelSwitch

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.TaskModelSwitch

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.TaskModelSwitch

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.TaskModelSwitch

IDNotIn applies the NotIn predicate on the ID field.

func LoadSession

func LoadSession(v bool) predicate.TaskModelSwitch

LoadSession applies equality check predicate on the "load_session" field. It's identical to LoadSessionEQ.

func LoadSessionEQ

func LoadSessionEQ(v bool) predicate.TaskModelSwitch

LoadSessionEQ applies the EQ predicate on the "load_session" field.

func LoadSessionNEQ

func LoadSessionNEQ(v bool) predicate.TaskModelSwitch

LoadSessionNEQ applies the NEQ predicate on the "load_session" field.

func Message

func Message(v string) predicate.TaskModelSwitch

Message applies equality check predicate on the "message" field. It's identical to MessageEQ.

func MessageContains

func MessageContains(v string) predicate.TaskModelSwitch

MessageContains applies the Contains predicate on the "message" field.

func MessageContainsFold

func MessageContainsFold(v string) predicate.TaskModelSwitch

MessageContainsFold applies the ContainsFold predicate on the "message" field.

func MessageEQ

func MessageEQ(v string) predicate.TaskModelSwitch

MessageEQ applies the EQ predicate on the "message" field.

func MessageEqualFold

func MessageEqualFold(v string) predicate.TaskModelSwitch

MessageEqualFold applies the EqualFold predicate on the "message" field.

func MessageGT

func MessageGT(v string) predicate.TaskModelSwitch

MessageGT applies the GT predicate on the "message" field.

func MessageGTE

func MessageGTE(v string) predicate.TaskModelSwitch

MessageGTE applies the GTE predicate on the "message" field.

func MessageHasPrefix

func MessageHasPrefix(v string) predicate.TaskModelSwitch

MessageHasPrefix applies the HasPrefix predicate on the "message" field.

func MessageHasSuffix

func MessageHasSuffix(v string) predicate.TaskModelSwitch

MessageHasSuffix applies the HasSuffix predicate on the "message" field.

func MessageIn

func MessageIn(vs ...string) predicate.TaskModelSwitch

MessageIn applies the In predicate on the "message" field.

func MessageLT

func MessageLT(v string) predicate.TaskModelSwitch

MessageLT applies the LT predicate on the "message" field.

func MessageLTE

func MessageLTE(v string) predicate.TaskModelSwitch

MessageLTE applies the LTE predicate on the "message" field.

func MessageNEQ

func MessageNEQ(v string) predicate.TaskModelSwitch

MessageNEQ applies the NEQ predicate on the "message" field.

func MessageNotIn

func MessageNotIn(vs ...string) predicate.TaskModelSwitch

MessageNotIn applies the NotIn predicate on the "message" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func RequestID

func RequestID(v string) predicate.TaskModelSwitch

RequestID applies equality check predicate on the "request_id" field. It's identical to RequestIDEQ.

func RequestIDContains

func RequestIDContains(v string) predicate.TaskModelSwitch

RequestIDContains applies the Contains predicate on the "request_id" field.

func RequestIDContainsFold

func RequestIDContainsFold(v string) predicate.TaskModelSwitch

RequestIDContainsFold applies the ContainsFold predicate on the "request_id" field.

func RequestIDEQ

func RequestIDEQ(v string) predicate.TaskModelSwitch

RequestIDEQ applies the EQ predicate on the "request_id" field.

func RequestIDEqualFold

func RequestIDEqualFold(v string) predicate.TaskModelSwitch

RequestIDEqualFold applies the EqualFold predicate on the "request_id" field.

func RequestIDGT

func RequestIDGT(v string) predicate.TaskModelSwitch

RequestIDGT applies the GT predicate on the "request_id" field.

func RequestIDGTE

func RequestIDGTE(v string) predicate.TaskModelSwitch

RequestIDGTE applies the GTE predicate on the "request_id" field.

func RequestIDHasPrefix

func RequestIDHasPrefix(v string) predicate.TaskModelSwitch

RequestIDHasPrefix applies the HasPrefix predicate on the "request_id" field.

func RequestIDHasSuffix

func RequestIDHasSuffix(v string) predicate.TaskModelSwitch

RequestIDHasSuffix applies the HasSuffix predicate on the "request_id" field.

func RequestIDIn

func RequestIDIn(vs ...string) predicate.TaskModelSwitch

RequestIDIn applies the In predicate on the "request_id" field.

func RequestIDLT

func RequestIDLT(v string) predicate.TaskModelSwitch

RequestIDLT applies the LT predicate on the "request_id" field.

func RequestIDLTE

func RequestIDLTE(v string) predicate.TaskModelSwitch

RequestIDLTE applies the LTE predicate on the "request_id" field.

func RequestIDNEQ

func RequestIDNEQ(v string) predicate.TaskModelSwitch

RequestIDNEQ applies the NEQ predicate on the "request_id" field.

func RequestIDNotIn

func RequestIDNotIn(vs ...string) predicate.TaskModelSwitch

RequestIDNotIn applies the NotIn predicate on the "request_id" field.

func SessionID

func SessionID(v string) predicate.TaskModelSwitch

SessionID applies equality check predicate on the "session_id" field. It's identical to SessionIDEQ.

func SessionIDContains

func SessionIDContains(v string) predicate.TaskModelSwitch

SessionIDContains applies the Contains predicate on the "session_id" field.

func SessionIDContainsFold

func SessionIDContainsFold(v string) predicate.TaskModelSwitch

SessionIDContainsFold applies the ContainsFold predicate on the "session_id" field.

func SessionIDEQ

func SessionIDEQ(v string) predicate.TaskModelSwitch

SessionIDEQ applies the EQ predicate on the "session_id" field.

func SessionIDEqualFold

func SessionIDEqualFold(v string) predicate.TaskModelSwitch

SessionIDEqualFold applies the EqualFold predicate on the "session_id" field.

func SessionIDGT

func SessionIDGT(v string) predicate.TaskModelSwitch

SessionIDGT applies the GT predicate on the "session_id" field.

func SessionIDGTE

func SessionIDGTE(v string) predicate.TaskModelSwitch

SessionIDGTE applies the GTE predicate on the "session_id" field.

func SessionIDHasPrefix

func SessionIDHasPrefix(v string) predicate.TaskModelSwitch

SessionIDHasPrefix applies the HasPrefix predicate on the "session_id" field.

func SessionIDHasSuffix

func SessionIDHasSuffix(v string) predicate.TaskModelSwitch

SessionIDHasSuffix applies the HasSuffix predicate on the "session_id" field.

func SessionIDIn

func SessionIDIn(vs ...string) predicate.TaskModelSwitch

SessionIDIn applies the In predicate on the "session_id" field.

func SessionIDLT

func SessionIDLT(v string) predicate.TaskModelSwitch

SessionIDLT applies the LT predicate on the "session_id" field.

func SessionIDLTE

func SessionIDLTE(v string) predicate.TaskModelSwitch

SessionIDLTE applies the LTE predicate on the "session_id" field.

func SessionIDNEQ

func SessionIDNEQ(v string) predicate.TaskModelSwitch

SessionIDNEQ applies the NEQ predicate on the "session_id" field.

func SessionIDNotIn

func SessionIDNotIn(vs ...string) predicate.TaskModelSwitch

SessionIDNotIn applies the NotIn predicate on the "session_id" field.

func Success

func Success(v bool) predicate.TaskModelSwitch

Success applies equality check predicate on the "success" field. It's identical to SuccessEQ.

func SuccessEQ

func SuccessEQ(v bool) predicate.TaskModelSwitch

SuccessEQ applies the EQ predicate on the "success" field.

func SuccessIsNil

func SuccessIsNil() predicate.TaskModelSwitch

SuccessIsNil applies the IsNil predicate on the "success" field.

func SuccessNEQ

func SuccessNEQ(v bool) predicate.TaskModelSwitch

SuccessNEQ applies the NEQ predicate on the "success" field.

func SuccessNotNil

func SuccessNotNil() predicate.TaskModelSwitch

SuccessNotNil applies the NotNil predicate on the "success" field.

func TaskID

TaskID applies equality check predicate on the "task_id" field. It's identical to TaskIDEQ.

func TaskIDEQ

func TaskIDEQ(v uuid.UUID) predicate.TaskModelSwitch

TaskIDEQ applies the EQ predicate on the "task_id" field.

func TaskIDIn

func TaskIDIn(vs ...uuid.UUID) predicate.TaskModelSwitch

TaskIDIn applies the In predicate on the "task_id" field.

func TaskIDNEQ

func TaskIDNEQ(v uuid.UUID) predicate.TaskModelSwitch

TaskIDNEQ applies the NEQ predicate on the "task_id" field.

func TaskIDNotIn

func TaskIDNotIn(vs ...uuid.UUID) predicate.TaskModelSwitch

TaskIDNotIn applies the NotIn predicate on the "task_id" field.

func ToModelID

func ToModelID(v uuid.UUID) predicate.TaskModelSwitch

ToModelID applies equality check predicate on the "to_model_id" field. It's identical to ToModelIDEQ.

func ToModelIDEQ

func ToModelIDEQ(v uuid.UUID) predicate.TaskModelSwitch

ToModelIDEQ applies the EQ predicate on the "to_model_id" field.

func ToModelIDIn

func ToModelIDIn(vs ...uuid.UUID) predicate.TaskModelSwitch

ToModelIDIn applies the In predicate on the "to_model_id" field.

func ToModelIDNEQ

func ToModelIDNEQ(v uuid.UUID) predicate.TaskModelSwitch

ToModelIDNEQ applies the NEQ predicate on the "to_model_id" field.

func ToModelIDNotIn

func ToModelIDNotIn(vs ...uuid.UUID) predicate.TaskModelSwitch

ToModelIDNotIn applies the NotIn predicate on the "to_model_id" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.TaskModelSwitch

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.TaskModelSwitch

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.TaskModelSwitch

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.TaskModelSwitch

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.TaskModelSwitch

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.TaskModelSwitch

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.TaskModelSwitch

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.TaskModelSwitch

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.TaskModelSwitch

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UserID

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

func UserIDEQ(v uuid.UUID) predicate.TaskModelSwitch

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...uuid.UUID) predicate.TaskModelSwitch

UserIDIn applies the In predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v uuid.UUID) predicate.TaskModelSwitch

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...uuid.UUID) predicate.TaskModelSwitch

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the TaskModelSwitch queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByFromModelField

func ByFromModelField(field string, opts ...sql.OrderTermOption) OrderOption

ByFromModelField orders the results by from_model field.

func ByFromModelID

func ByFromModelID(opts ...sql.OrderTermOption) OrderOption

ByFromModelID orders the results by the from_model_id field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLoadSession

func ByLoadSession(opts ...sql.OrderTermOption) OrderOption

ByLoadSession orders the results by the load_session field.

func ByMessage

func ByMessage(opts ...sql.OrderTermOption) OrderOption

ByMessage orders the results by the message field.

func ByRequestID

func ByRequestID(opts ...sql.OrderTermOption) OrderOption

ByRequestID orders the results by the request_id field.

func BySessionID

func BySessionID(opts ...sql.OrderTermOption) OrderOption

BySessionID orders the results by the session_id field.

func BySuccess

func BySuccess(opts ...sql.OrderTermOption) OrderOption

BySuccess orders the results by the success field.

func ByTaskField

func ByTaskField(field string, opts ...sql.OrderTermOption) OrderOption

ByTaskField orders the results by task field.

func ByTaskID

func ByTaskID(opts ...sql.OrderTermOption) OrderOption

ByTaskID orders the results by the task_id field.

func ByToModelField

func ByToModelField(field string, opts ...sql.OrderTermOption) OrderOption

ByToModelField orders the results by to_model field.

func ByToModelID

func ByToModelID(opts ...sql.OrderTermOption) OrderOption

ByToModelID orders the results by the to_model_id field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to