taskusagestat

package
v0.0.0-...-5f31c4b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the taskusagestat type in the database.
	Label = "task_usage_stat"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldTaskID holds the string denoting the task_id field in the database.
	FieldTaskID = "task_id"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// FieldModel holds the string denoting the model field in the database.
	FieldModel = "model"
	// FieldInputTokens holds the string denoting the input_tokens field in the database.
	FieldInputTokens = "input_tokens"
	// FieldOutputTokens holds the string denoting the output_tokens field in the database.
	FieldOutputTokens = "output_tokens"
	// FieldTotalTokens holds the string denoting the total_tokens field in the database.
	FieldTotalTokens = "total_tokens"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// Table holds the table name of the taskusagestat in the database.
	Table = "task_usage_stats"
)

Variables

var (
	// DefaultModel holds the default value on creation for the "model" field.
	DefaultModel string
	// DefaultInputTokens holds the default value on creation for the "input_tokens" field.
	DefaultInputTokens int64
	// DefaultOutputTokens holds the default value on creation for the "output_tokens" field.
	DefaultOutputTokens int64
	// DefaultTotalTokens holds the default value on creation for the "total_tokens" field.
	DefaultTotalTokens int64
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for taskusagestat fields.

Functions

func And

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.TaskUsageStat

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.TaskUsageStat

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.TaskUsageStat

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.TaskUsageStat

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.TaskUsageStat

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.TaskUsageStat

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.TaskUsageStat

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.TaskUsageStat

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.TaskUsageStat

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.TaskUsageStat

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.TaskUsageStat

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.TaskUsageStat

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.TaskUsageStat

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.TaskUsageStat

IDNotIn applies the NotIn predicate on the ID field.

func InputTokens

func InputTokens(v int64) predicate.TaskUsageStat

InputTokens applies equality check predicate on the "input_tokens" field. It's identical to InputTokensEQ.

func InputTokensEQ

func InputTokensEQ(v int64) predicate.TaskUsageStat

InputTokensEQ applies the EQ predicate on the "input_tokens" field.

func InputTokensGT

func InputTokensGT(v int64) predicate.TaskUsageStat

InputTokensGT applies the GT predicate on the "input_tokens" field.

func InputTokensGTE

func InputTokensGTE(v int64) predicate.TaskUsageStat

InputTokensGTE applies the GTE predicate on the "input_tokens" field.

func InputTokensIn

func InputTokensIn(vs ...int64) predicate.TaskUsageStat

InputTokensIn applies the In predicate on the "input_tokens" field.

func InputTokensLT

func InputTokensLT(v int64) predicate.TaskUsageStat

InputTokensLT applies the LT predicate on the "input_tokens" field.

func InputTokensLTE

func InputTokensLTE(v int64) predicate.TaskUsageStat

InputTokensLTE applies the LTE predicate on the "input_tokens" field.

func InputTokensNEQ

func InputTokensNEQ(v int64) predicate.TaskUsageStat

InputTokensNEQ applies the NEQ predicate on the "input_tokens" field.

func InputTokensNotIn

func InputTokensNotIn(vs ...int64) predicate.TaskUsageStat

InputTokensNotIn applies the NotIn predicate on the "input_tokens" field.

func Model

Model applies equality check predicate on the "model" field. It's identical to ModelEQ.

func ModelContains

func ModelContains(v string) predicate.TaskUsageStat

ModelContains applies the Contains predicate on the "model" field.

func ModelContainsFold

func ModelContainsFold(v string) predicate.TaskUsageStat

ModelContainsFold applies the ContainsFold predicate on the "model" field.

func ModelEQ

func ModelEQ(v string) predicate.TaskUsageStat

ModelEQ applies the EQ predicate on the "model" field.

func ModelEqualFold

func ModelEqualFold(v string) predicate.TaskUsageStat

ModelEqualFold applies the EqualFold predicate on the "model" field.

func ModelGT

func ModelGT(v string) predicate.TaskUsageStat

ModelGT applies the GT predicate on the "model" field.

func ModelGTE

func ModelGTE(v string) predicate.TaskUsageStat

ModelGTE applies the GTE predicate on the "model" field.

func ModelHasPrefix

func ModelHasPrefix(v string) predicate.TaskUsageStat

ModelHasPrefix applies the HasPrefix predicate on the "model" field.

func ModelHasSuffix

func ModelHasSuffix(v string) predicate.TaskUsageStat

ModelHasSuffix applies the HasSuffix predicate on the "model" field.

func ModelIn

func ModelIn(vs ...string) predicate.TaskUsageStat

ModelIn applies the In predicate on the "model" field.

func ModelLT

func ModelLT(v string) predicate.TaskUsageStat

ModelLT applies the LT predicate on the "model" field.

func ModelLTE

func ModelLTE(v string) predicate.TaskUsageStat

ModelLTE applies the LTE predicate on the "model" field.

func ModelNEQ

func ModelNEQ(v string) predicate.TaskUsageStat

ModelNEQ applies the NEQ predicate on the "model" field.

func ModelNotIn

func ModelNotIn(vs ...string) predicate.TaskUsageStat

ModelNotIn applies the NotIn predicate on the "model" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func OutputTokens

func OutputTokens(v int64) predicate.TaskUsageStat

OutputTokens applies equality check predicate on the "output_tokens" field. It's identical to OutputTokensEQ.

func OutputTokensEQ

func OutputTokensEQ(v int64) predicate.TaskUsageStat

OutputTokensEQ applies the EQ predicate on the "output_tokens" field.

func OutputTokensGT

func OutputTokensGT(v int64) predicate.TaskUsageStat

OutputTokensGT applies the GT predicate on the "output_tokens" field.

func OutputTokensGTE

func OutputTokensGTE(v int64) predicate.TaskUsageStat

OutputTokensGTE applies the GTE predicate on the "output_tokens" field.

func OutputTokensIn

func OutputTokensIn(vs ...int64) predicate.TaskUsageStat

OutputTokensIn applies the In predicate on the "output_tokens" field.

func OutputTokensLT

func OutputTokensLT(v int64) predicate.TaskUsageStat

OutputTokensLT applies the LT predicate on the "output_tokens" field.

func OutputTokensLTE

func OutputTokensLTE(v int64) predicate.TaskUsageStat

OutputTokensLTE applies the LTE predicate on the "output_tokens" field.

func OutputTokensNEQ

func OutputTokensNEQ(v int64) predicate.TaskUsageStat

OutputTokensNEQ applies the NEQ predicate on the "output_tokens" field.

func OutputTokensNotIn

func OutputTokensNotIn(vs ...int64) predicate.TaskUsageStat

OutputTokensNotIn applies the NotIn predicate on the "output_tokens" field.

func TaskID

func TaskID(v uuid.UUID) predicate.TaskUsageStat

TaskID applies equality check predicate on the "task_id" field. It's identical to TaskIDEQ.

func TaskIDEQ

func TaskIDEQ(v uuid.UUID) predicate.TaskUsageStat

TaskIDEQ applies the EQ predicate on the "task_id" field.

func TaskIDGT

func TaskIDGT(v uuid.UUID) predicate.TaskUsageStat

TaskIDGT applies the GT predicate on the "task_id" field.

func TaskIDGTE

func TaskIDGTE(v uuid.UUID) predicate.TaskUsageStat

TaskIDGTE applies the GTE predicate on the "task_id" field.

func TaskIDIn

func TaskIDIn(vs ...uuid.UUID) predicate.TaskUsageStat

TaskIDIn applies the In predicate on the "task_id" field.

func TaskIDLT

func TaskIDLT(v uuid.UUID) predicate.TaskUsageStat

TaskIDLT applies the LT predicate on the "task_id" field.

func TaskIDLTE

func TaskIDLTE(v uuid.UUID) predicate.TaskUsageStat

TaskIDLTE applies the LTE predicate on the "task_id" field.

func TaskIDNEQ

func TaskIDNEQ(v uuid.UUID) predicate.TaskUsageStat

TaskIDNEQ applies the NEQ predicate on the "task_id" field.

func TaskIDNotIn

func TaskIDNotIn(vs ...uuid.UUID) predicate.TaskUsageStat

TaskIDNotIn applies the NotIn predicate on the "task_id" field.

func TotalTokens

func TotalTokens(v int64) predicate.TaskUsageStat

TotalTokens applies equality check predicate on the "total_tokens" field. It's identical to TotalTokensEQ.

func TotalTokensEQ

func TotalTokensEQ(v int64) predicate.TaskUsageStat

TotalTokensEQ applies the EQ predicate on the "total_tokens" field.

func TotalTokensGT

func TotalTokensGT(v int64) predicate.TaskUsageStat

TotalTokensGT applies the GT predicate on the "total_tokens" field.

func TotalTokensGTE

func TotalTokensGTE(v int64) predicate.TaskUsageStat

TotalTokensGTE applies the GTE predicate on the "total_tokens" field.

func TotalTokensIn

func TotalTokensIn(vs ...int64) predicate.TaskUsageStat

TotalTokensIn applies the In predicate on the "total_tokens" field.

func TotalTokensLT

func TotalTokensLT(v int64) predicate.TaskUsageStat

TotalTokensLT applies the LT predicate on the "total_tokens" field.

func TotalTokensLTE

func TotalTokensLTE(v int64) predicate.TaskUsageStat

TotalTokensLTE applies the LTE predicate on the "total_tokens" field.

func TotalTokensNEQ

func TotalTokensNEQ(v int64) predicate.TaskUsageStat

TotalTokensNEQ applies the NEQ predicate on the "total_tokens" field.

func TotalTokensNotIn

func TotalTokensNotIn(vs ...int64) predicate.TaskUsageStat

TotalTokensNotIn applies the NotIn predicate on the "total_tokens" field.

func UserID

func UserID(v uuid.UUID) predicate.TaskUsageStat

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

func UserIDEQ(v uuid.UUID) predicate.TaskUsageStat

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDGT

func UserIDGT(v uuid.UUID) predicate.TaskUsageStat

UserIDGT applies the GT predicate on the "user_id" field.

func UserIDGTE

func UserIDGTE(v uuid.UUID) predicate.TaskUsageStat

UserIDGTE applies the GTE predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...uuid.UUID) predicate.TaskUsageStat

UserIDIn applies the In predicate on the "user_id" field.

func UserIDLT

func UserIDLT(v uuid.UUID) predicate.TaskUsageStat

UserIDLT applies the LT predicate on the "user_id" field.

func UserIDLTE

func UserIDLTE(v uuid.UUID) predicate.TaskUsageStat

UserIDLTE applies the LTE predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v uuid.UUID) predicate.TaskUsageStat

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...uuid.UUID) predicate.TaskUsageStat

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the TaskUsageStat queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByInputTokens

func ByInputTokens(opts ...sql.OrderTermOption) OrderOption

ByInputTokens orders the results by the input_tokens field.

func ByModel

func ByModel(opts ...sql.OrderTermOption) OrderOption

ByModel orders the results by the model field.

func ByOutputTokens

func ByOutputTokens(opts ...sql.OrderTermOption) OrderOption

ByOutputTokens orders the results by the output_tokens field.

func ByTaskID

func ByTaskID(opts ...sql.OrderTermOption) OrderOption

ByTaskID orders the results by the task_id field.

func ByTotalTokens

func ByTotalTokens(opts ...sql.OrderTermOption) OrderOption

ByTotalTokens orders the results by the total_tokens field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to