Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.TeamGroupHost) predicate.TeamGroupHost
- func CreatedAt(v time.Time) predicate.TeamGroupHost
- func CreatedAtEQ(v time.Time) predicate.TeamGroupHost
- func CreatedAtGT(v time.Time) predicate.TeamGroupHost
- func CreatedAtGTE(v time.Time) predicate.TeamGroupHost
- func CreatedAtIn(vs ...time.Time) predicate.TeamGroupHost
- func CreatedAtLT(v time.Time) predicate.TeamGroupHost
- func CreatedAtLTE(v time.Time) predicate.TeamGroupHost
- func CreatedAtNEQ(v time.Time) predicate.TeamGroupHost
- func CreatedAtNotIn(vs ...time.Time) predicate.TeamGroupHost
- func GroupID(v uuid.UUID) predicate.TeamGroupHost
- func GroupIDEQ(v uuid.UUID) predicate.TeamGroupHost
- func GroupIDIn(vs ...uuid.UUID) predicate.TeamGroupHost
- func GroupIDNEQ(v uuid.UUID) predicate.TeamGroupHost
- func GroupIDNotIn(vs ...uuid.UUID) predicate.TeamGroupHost
- func HasGroup() predicate.TeamGroupHost
- func HasGroupWith(preds ...predicate.TeamGroup) predicate.TeamGroupHost
- func HasHost() predicate.TeamGroupHost
- func HasHostWith(preds ...predicate.Host) predicate.TeamGroupHost
- func HostID(v string) predicate.TeamGroupHost
- func HostIDContains(v string) predicate.TeamGroupHost
- func HostIDContainsFold(v string) predicate.TeamGroupHost
- func HostIDEQ(v string) predicate.TeamGroupHost
- func HostIDEqualFold(v string) predicate.TeamGroupHost
- func HostIDGT(v string) predicate.TeamGroupHost
- func HostIDGTE(v string) predicate.TeamGroupHost
- func HostIDHasPrefix(v string) predicate.TeamGroupHost
- func HostIDHasSuffix(v string) predicate.TeamGroupHost
- func HostIDIn(vs ...string) predicate.TeamGroupHost
- func HostIDLT(v string) predicate.TeamGroupHost
- func HostIDLTE(v string) predicate.TeamGroupHost
- func HostIDNEQ(v string) predicate.TeamGroupHost
- func HostIDNotIn(vs ...string) predicate.TeamGroupHost
- func ID(id uuid.UUID) predicate.TeamGroupHost
- func IDEQ(id uuid.UUID) predicate.TeamGroupHost
- func IDGT(id uuid.UUID) predicate.TeamGroupHost
- func IDGTE(id uuid.UUID) predicate.TeamGroupHost
- func IDIn(ids ...uuid.UUID) predicate.TeamGroupHost
- func IDLT(id uuid.UUID) predicate.TeamGroupHost
- func IDLTE(id uuid.UUID) predicate.TeamGroupHost
- func IDNEQ(id uuid.UUID) predicate.TeamGroupHost
- func IDNotIn(ids ...uuid.UUID) predicate.TeamGroupHost
- func Not(p predicate.TeamGroupHost) predicate.TeamGroupHost
- func Or(predicates ...predicate.TeamGroupHost) predicate.TeamGroupHost
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByGroupField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByGroupID(opts ...sql.OrderTermOption) OrderOption
- func ByHostField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByHostID(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the teamgrouphost type in the database. Label = "team_group_host" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldGroupID holds the string denoting the group_id field in the database. FieldGroupID = "group_id" // FieldHostID holds the string denoting the host_id field in the database. FieldHostID = "host_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // EdgeGroup holds the string denoting the group edge name in mutations. EdgeGroup = "group" // EdgeHost holds the string denoting the host edge name in mutations. EdgeHost = "host" // Table holds the table name of the teamgrouphost in the database. Table = "team_group_hosts" // GroupTable is the table that holds the group relation/edge. GroupTable = "team_group_hosts" // GroupInverseTable is the table name for the TeamGroup entity. // It exists in this package in order to avoid circular dependency with the "teamgroup" package. GroupInverseTable = "team_groups" // GroupColumn is the table column denoting the group relation/edge. GroupColumn = "group_id" // HostTable is the table that holds the host relation/edge. HostTable = "team_group_hosts" // HostInverseTable is the table name for the Host entity. // It exists in this package in order to avoid circular dependency with the "host" package. HostInverseTable = "hosts" // HostColumn is the table column denoting the host relation/edge. HostColumn = "host_id" )
Variables ¶
var Columns = []string{ FieldID, FieldGroupID, FieldHostID, FieldCreatedAt, }
Columns holds all SQL columns for teamgrouphost fields.
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time )
Functions ¶
func And ¶
func And(predicates ...predicate.TeamGroupHost) predicate.TeamGroupHost
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.TeamGroupHost
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.TeamGroupHost
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.TeamGroupHost
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.TeamGroupHost
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.TeamGroupHost
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.TeamGroupHost
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.TeamGroupHost
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.TeamGroupHost
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.TeamGroupHost
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func GroupID ¶
func GroupID(v uuid.UUID) predicate.TeamGroupHost
GroupID applies equality check predicate on the "group_id" field. It's identical to GroupIDEQ.
func GroupIDEQ ¶
func GroupIDEQ(v uuid.UUID) predicate.TeamGroupHost
GroupIDEQ applies the EQ predicate on the "group_id" field.
func GroupIDIn ¶
func GroupIDIn(vs ...uuid.UUID) predicate.TeamGroupHost
GroupIDIn applies the In predicate on the "group_id" field.
func GroupIDNEQ ¶
func GroupIDNEQ(v uuid.UUID) predicate.TeamGroupHost
GroupIDNEQ applies the NEQ predicate on the "group_id" field.
func GroupIDNotIn ¶
func GroupIDNotIn(vs ...uuid.UUID) predicate.TeamGroupHost
GroupIDNotIn applies the NotIn predicate on the "group_id" field.
func HasGroup ¶
func HasGroup() predicate.TeamGroupHost
HasGroup applies the HasEdge predicate on the "group" edge.
func HasGroupWith ¶
func HasGroupWith(preds ...predicate.TeamGroup) predicate.TeamGroupHost
HasGroupWith applies the HasEdge predicate on the "group" edge with a given conditions (other predicates).
func HasHost ¶
func HasHost() predicate.TeamGroupHost
HasHost applies the HasEdge predicate on the "host" edge.
func HasHostWith ¶
func HasHostWith(preds ...predicate.Host) predicate.TeamGroupHost
HasHostWith applies the HasEdge predicate on the "host" edge with a given conditions (other predicates).
func HostID ¶
func HostID(v string) predicate.TeamGroupHost
HostID applies equality check predicate on the "host_id" field. It's identical to HostIDEQ.
func HostIDContains ¶
func HostIDContains(v string) predicate.TeamGroupHost
HostIDContains applies the Contains predicate on the "host_id" field.
func HostIDContainsFold ¶
func HostIDContainsFold(v string) predicate.TeamGroupHost
HostIDContainsFold applies the ContainsFold predicate on the "host_id" field.
func HostIDEQ ¶
func HostIDEQ(v string) predicate.TeamGroupHost
HostIDEQ applies the EQ predicate on the "host_id" field.
func HostIDEqualFold ¶
func HostIDEqualFold(v string) predicate.TeamGroupHost
HostIDEqualFold applies the EqualFold predicate on the "host_id" field.
func HostIDGT ¶
func HostIDGT(v string) predicate.TeamGroupHost
HostIDGT applies the GT predicate on the "host_id" field.
func HostIDGTE ¶
func HostIDGTE(v string) predicate.TeamGroupHost
HostIDGTE applies the GTE predicate on the "host_id" field.
func HostIDHasPrefix ¶
func HostIDHasPrefix(v string) predicate.TeamGroupHost
HostIDHasPrefix applies the HasPrefix predicate on the "host_id" field.
func HostIDHasSuffix ¶
func HostIDHasSuffix(v string) predicate.TeamGroupHost
HostIDHasSuffix applies the HasSuffix predicate on the "host_id" field.
func HostIDIn ¶
func HostIDIn(vs ...string) predicate.TeamGroupHost
HostIDIn applies the In predicate on the "host_id" field.
func HostIDLT ¶
func HostIDLT(v string) predicate.TeamGroupHost
HostIDLT applies the LT predicate on the "host_id" field.
func HostIDLTE ¶
func HostIDLTE(v string) predicate.TeamGroupHost
HostIDLTE applies the LTE predicate on the "host_id" field.
func HostIDNEQ ¶
func HostIDNEQ(v string) predicate.TeamGroupHost
HostIDNEQ applies the NEQ predicate on the "host_id" field.
func HostIDNotIn ¶
func HostIDNotIn(vs ...string) predicate.TeamGroupHost
HostIDNotIn applies the NotIn predicate on the "host_id" field.
func ID ¶
func ID(id uuid.UUID) predicate.TeamGroupHost
ID filters vertices based on their ID field.
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.TeamGroupHost
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.TeamGroupHost
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.TeamGroupHost
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.TeamGroupHost
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.TeamGroupHost
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.TeamGroupHost
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.TeamGroupHost
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.TeamGroupHost
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.TeamGroupHost) predicate.TeamGroupHost
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.TeamGroupHost) predicate.TeamGroupHost
Or groups predicates with the OR operator between them.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the TeamGroupHost queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByGroupField ¶
func ByGroupField(field string, opts ...sql.OrderTermOption) OrderOption
ByGroupField orders the results by group field.
func ByGroupID ¶
func ByGroupID(opts ...sql.OrderTermOption) OrderOption
ByGroupID orders the results by the group_id field.
func ByHostField ¶
func ByHostField(field string, opts ...sql.OrderTermOption) OrderOption
ByHostField orders the results by host field.
func ByHostID ¶
func ByHostID(opts ...sql.OrderTermOption) OrderOption
ByHostID orders the results by the host_id field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.