Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.MCPTool) predicate.MCPTool
- func CreatedAt(v time.Time) predicate.MCPTool
- func CreatedAtEQ(v time.Time) predicate.MCPTool
- func CreatedAtGT(v time.Time) predicate.MCPTool
- func CreatedAtGTE(v time.Time) predicate.MCPTool
- func CreatedAtIn(vs ...time.Time) predicate.MCPTool
- func CreatedAtLT(v time.Time) predicate.MCPTool
- func CreatedAtLTE(v time.Time) predicate.MCPTool
- func CreatedAtNEQ(v time.Time) predicate.MCPTool
- func CreatedAtNotIn(vs ...time.Time) predicate.MCPTool
- func DeletedAt(v time.Time) predicate.MCPTool
- func DeletedAtEQ(v time.Time) predicate.MCPTool
- func DeletedAtGT(v time.Time) predicate.MCPTool
- func DeletedAtGTE(v time.Time) predicate.MCPTool
- func DeletedAtIn(vs ...time.Time) predicate.MCPTool
- func DeletedAtIsNil() predicate.MCPTool
- func DeletedAtLT(v time.Time) predicate.MCPTool
- func DeletedAtLTE(v time.Time) predicate.MCPTool
- func DeletedAtNEQ(v time.Time) predicate.MCPTool
- func DeletedAtNotIn(vs ...time.Time) predicate.MCPTool
- func DeletedAtNotNil() predicate.MCPTool
- func Description(v string) predicate.MCPTool
- func DescriptionContains(v string) predicate.MCPTool
- func DescriptionContainsFold(v string) predicate.MCPTool
- func DescriptionEQ(v string) predicate.MCPTool
- func DescriptionEqualFold(v string) predicate.MCPTool
- func DescriptionGT(v string) predicate.MCPTool
- func DescriptionGTE(v string) predicate.MCPTool
- func DescriptionHasPrefix(v string) predicate.MCPTool
- func DescriptionHasSuffix(v string) predicate.MCPTool
- func DescriptionIn(vs ...string) predicate.MCPTool
- func DescriptionIsNil() predicate.MCPTool
- func DescriptionLT(v string) predicate.MCPTool
- func DescriptionLTE(v string) predicate.MCPTool
- func DescriptionNEQ(v string) predicate.MCPTool
- func DescriptionNotIn(vs ...string) predicate.MCPTool
- func DescriptionNotNil() predicate.MCPTool
- func Enabled(v bool) predicate.MCPTool
- func EnabledEQ(v bool) predicate.MCPTool
- func EnabledNEQ(v bool) predicate.MCPTool
- func HasUpstream() predicate.MCPTool
- func HasUpstreamWith(preds ...predicate.MCPUpstream) predicate.MCPTool
- func ID(id uuid.UUID) predicate.MCPTool
- func IDEQ(id uuid.UUID) predicate.MCPTool
- func IDGT(id uuid.UUID) predicate.MCPTool
- func IDGTE(id uuid.UUID) predicate.MCPTool
- func IDIn(ids ...uuid.UUID) predicate.MCPTool
- func IDLT(id uuid.UUID) predicate.MCPTool
- func IDLTE(id uuid.UUID) predicate.MCPTool
- func IDNEQ(id uuid.UUID) predicate.MCPTool
- func IDNotIn(ids ...uuid.UUID) predicate.MCPTool
- func InputSchemaIsNil() predicate.MCPTool
- func InputSchemaNotNil() predicate.MCPTool
- func Name(v string) predicate.MCPTool
- func NameContains(v string) predicate.MCPTool
- func NameContainsFold(v string) predicate.MCPTool
- func NameEQ(v string) predicate.MCPTool
- func NameEqualFold(v string) predicate.MCPTool
- func NameGT(v string) predicate.MCPTool
- func NameGTE(v string) predicate.MCPTool
- func NameHasPrefix(v string) predicate.MCPTool
- func NameHasSuffix(v string) predicate.MCPTool
- func NameIn(vs ...string) predicate.MCPTool
- func NameLT(v string) predicate.MCPTool
- func NameLTE(v string) predicate.MCPTool
- func NameNEQ(v string) predicate.MCPTool
- func NameNotIn(vs ...string) predicate.MCPTool
- func NamespacedName(v string) predicate.MCPTool
- func NamespacedNameContains(v string) predicate.MCPTool
- func NamespacedNameContainsFold(v string) predicate.MCPTool
- func NamespacedNameEQ(v string) predicate.MCPTool
- func NamespacedNameEqualFold(v string) predicate.MCPTool
- func NamespacedNameGT(v string) predicate.MCPTool
- func NamespacedNameGTE(v string) predicate.MCPTool
- func NamespacedNameHasPrefix(v string) predicate.MCPTool
- func NamespacedNameHasSuffix(v string) predicate.MCPTool
- func NamespacedNameIn(vs ...string) predicate.MCPTool
- func NamespacedNameLT(v string) predicate.MCPTool
- func NamespacedNameLTE(v string) predicate.MCPTool
- func NamespacedNameNEQ(v string) predicate.MCPTool
- func NamespacedNameNotIn(vs ...string) predicate.MCPTool
- func Not(p predicate.MCPTool) predicate.MCPTool
- func Or(predicates ...predicate.MCPTool) predicate.MCPTool
- func Price(v int64) predicate.MCPTool
- func PriceEQ(v int64) predicate.MCPTool
- func PriceGT(v int64) predicate.MCPTool
- func PriceGTE(v int64) predicate.MCPTool
- func PriceIn(vs ...int64) predicate.MCPTool
- func PriceLT(v int64) predicate.MCPTool
- func PriceLTE(v int64) predicate.MCPTool
- func PriceNEQ(v int64) predicate.MCPTool
- func PriceNotIn(vs ...int64) predicate.MCPTool
- func ScopeEQ(v Scope) predicate.MCPTool
- func ScopeIn(vs ...Scope) predicate.MCPTool
- func ScopeNEQ(v Scope) predicate.MCPTool
- func ScopeNotIn(vs ...Scope) predicate.MCPTool
- func ScopeValidator(s Scope) error
- func SyncedAt(v time.Time) predicate.MCPTool
- func SyncedAtEQ(v time.Time) predicate.MCPTool
- func SyncedAtGT(v time.Time) predicate.MCPTool
- func SyncedAtGTE(v time.Time) predicate.MCPTool
- func SyncedAtIn(vs ...time.Time) predicate.MCPTool
- func SyncedAtIsNil() predicate.MCPTool
- func SyncedAtLT(v time.Time) predicate.MCPTool
- func SyncedAtLTE(v time.Time) predicate.MCPTool
- func SyncedAtNEQ(v time.Time) predicate.MCPTool
- func SyncedAtNotIn(vs ...time.Time) predicate.MCPTool
- func SyncedAtNotNil() predicate.MCPTool
- func UpdatedAt(v time.Time) predicate.MCPTool
- func UpdatedAtEQ(v time.Time) predicate.MCPTool
- func UpdatedAtGT(v time.Time) predicate.MCPTool
- func UpdatedAtGTE(v time.Time) predicate.MCPTool
- func UpdatedAtIn(vs ...time.Time) predicate.MCPTool
- func UpdatedAtLT(v time.Time) predicate.MCPTool
- func UpdatedAtLTE(v time.Time) predicate.MCPTool
- func UpdatedAtNEQ(v time.Time) predicate.MCPTool
- func UpdatedAtNotIn(vs ...time.Time) predicate.MCPTool
- func UpstreamID(v uuid.UUID) predicate.MCPTool
- func UpstreamIDEQ(v uuid.UUID) predicate.MCPTool
- func UpstreamIDIn(vs ...uuid.UUID) predicate.MCPTool
- func UpstreamIDNEQ(v uuid.UUID) predicate.MCPTool
- func UpstreamIDNotIn(vs ...uuid.UUID) predicate.MCPTool
- func UserID(v uuid.UUID) predicate.MCPTool
- func UserIDEQ(v uuid.UUID) predicate.MCPTool
- func UserIDGT(v uuid.UUID) predicate.MCPTool
- func UserIDGTE(v uuid.UUID) predicate.MCPTool
- func UserIDIn(vs ...uuid.UUID) predicate.MCPTool
- func UserIDIsNil() predicate.MCPTool
- func UserIDLT(v uuid.UUID) predicate.MCPTool
- func UserIDLTE(v uuid.UUID) predicate.MCPTool
- func UserIDNEQ(v uuid.UUID) predicate.MCPTool
- func UserIDNotIn(vs ...uuid.UUID) predicate.MCPTool
- func UserIDNotNil() predicate.MCPTool
- func ValidColumn(column string) bool
- func VersionHash(v string) predicate.MCPTool
- func VersionHashContains(v string) predicate.MCPTool
- func VersionHashContainsFold(v string) predicate.MCPTool
- func VersionHashEQ(v string) predicate.MCPTool
- func VersionHashEqualFold(v string) predicate.MCPTool
- func VersionHashGT(v string) predicate.MCPTool
- func VersionHashGTE(v string) predicate.MCPTool
- func VersionHashHasPrefix(v string) predicate.MCPTool
- func VersionHashHasSuffix(v string) predicate.MCPTool
- func VersionHashIn(vs ...string) predicate.MCPTool
- func VersionHashIsNil() predicate.MCPTool
- func VersionHashLT(v string) predicate.MCPTool
- func VersionHashLTE(v string) predicate.MCPTool
- func VersionHashNEQ(v string) predicate.MCPTool
- func VersionHashNotIn(vs ...string) predicate.MCPTool
- func VersionHashNotNil() predicate.MCPTool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDescription(opts ...sql.OrderTermOption) OrderOption
- func ByEnabled(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByNamespacedName(opts ...sql.OrderTermOption) OrderOption
- func ByPrice(opts ...sql.OrderTermOption) OrderOption
- func ByScope(opts ...sql.OrderTermOption) OrderOption
- func BySyncedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpstreamField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByUpstreamID(opts ...sql.OrderTermOption) OrderOption
- func ByUserID(opts ...sql.OrderTermOption) OrderOption
- func ByVersionHash(opts ...sql.OrderTermOption) OrderOption
- type Scope
Constants ¶
const ( // Label holds the string label denoting the mcptool type in the database. Label = "mcp_tool" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldUpstreamID holds the string denoting the upstream_id field in the database. FieldUpstreamID = "upstream_id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldNamespacedName holds the string denoting the namespaced_name field in the database. FieldNamespacedName = "namespaced_name" // FieldScope holds the string denoting the scope field in the database. FieldScope = "scope" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldInputSchema holds the string denoting the input_schema field in the database. FieldInputSchema = "input_schema" // FieldPrice holds the string denoting the price field in the database. FieldPrice = "price" // FieldEnabled holds the string denoting the enabled field in the database. FieldEnabled = "enabled" // FieldVersionHash holds the string denoting the version_hash field in the database. FieldVersionHash = "version_hash" // FieldSyncedAt holds the string denoting the synced_at field in the database. FieldSyncedAt = "synced_at" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeUpstream holds the string denoting the upstream edge name in mutations. EdgeUpstream = "upstream" // Table holds the table name of the mcptool in the database. Table = "mcp_tools" // UpstreamTable is the table that holds the upstream relation/edge. UpstreamTable = "mcp_tools" // UpstreamInverseTable is the table name for the MCPUpstream entity. // It exists in this package in order to avoid circular dependency with the "mcpupstream" package. UpstreamInverseTable = "mcp_upstreams" // UpstreamColumn is the table column denoting the upstream relation/edge. UpstreamColumn = "upstream_id" )
Variables ¶
var ( Hooks [1]ent.Hook Interceptors [1]ent.Interceptor // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // NamespacedNameValidator is a validator for the "namespaced_name" field. It is called by the builders before save. NamespacedNameValidator func(string) error // DefaultPrice holds the default value on creation for the "price" field. DefaultPrice int64 // DefaultEnabled holds the default value on creation for the "enabled" field. DefaultEnabled bool // VersionHashValidator is a validator for the "version_hash" field. It is called by the builders before save. VersionHashValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/chaitin/MonkeyCode/backend/db/runtime"
var Columns = []string{ FieldID, FieldDeletedAt, FieldUpstreamID, FieldName, FieldNamespacedName, FieldScope, FieldUserID, FieldDescription, FieldInputSchema, FieldPrice, FieldEnabled, FieldVersionHash, FieldSyncedAt, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for mcptool fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func Description ¶
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
DescriptionIn applies the In predicate on the "description" field.
func DescriptionIsNil ¶
DescriptionIsNil applies the IsNil predicate on the "description" field.
func DescriptionLT ¶
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
DescriptionNotIn applies the NotIn predicate on the "description" field.
func DescriptionNotNil ¶
DescriptionNotNil applies the NotNil predicate on the "description" field.
func Enabled ¶
Enabled applies equality check predicate on the "enabled" field. It's identical to EnabledEQ.
func EnabledNEQ ¶
EnabledNEQ applies the NEQ predicate on the "enabled" field.
func HasUpstream ¶
HasUpstream applies the HasEdge predicate on the "upstream" edge.
func HasUpstreamWith ¶
func HasUpstreamWith(preds ...predicate.MCPUpstream) predicate.MCPTool
HasUpstreamWith applies the HasEdge predicate on the "upstream" edge with a given conditions (other predicates).
func InputSchemaIsNil ¶
InputSchemaIsNil applies the IsNil predicate on the "input_schema" field.
func InputSchemaNotNil ¶
InputSchemaNotNil applies the NotNil predicate on the "input_schema" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NamespacedName ¶
NamespacedName applies equality check predicate on the "namespaced_name" field. It's identical to NamespacedNameEQ.
func NamespacedNameContains ¶
NamespacedNameContains applies the Contains predicate on the "namespaced_name" field.
func NamespacedNameContainsFold ¶
NamespacedNameContainsFold applies the ContainsFold predicate on the "namespaced_name" field.
func NamespacedNameEQ ¶
NamespacedNameEQ applies the EQ predicate on the "namespaced_name" field.
func NamespacedNameEqualFold ¶
NamespacedNameEqualFold applies the EqualFold predicate on the "namespaced_name" field.
func NamespacedNameGT ¶
NamespacedNameGT applies the GT predicate on the "namespaced_name" field.
func NamespacedNameGTE ¶
NamespacedNameGTE applies the GTE predicate on the "namespaced_name" field.
func NamespacedNameHasPrefix ¶
NamespacedNameHasPrefix applies the HasPrefix predicate on the "namespaced_name" field.
func NamespacedNameHasSuffix ¶
NamespacedNameHasSuffix applies the HasSuffix predicate on the "namespaced_name" field.
func NamespacedNameIn ¶
NamespacedNameIn applies the In predicate on the "namespaced_name" field.
func NamespacedNameLT ¶
NamespacedNameLT applies the LT predicate on the "namespaced_name" field.
func NamespacedNameLTE ¶
NamespacedNameLTE applies the LTE predicate on the "namespaced_name" field.
func NamespacedNameNEQ ¶
NamespacedNameNEQ applies the NEQ predicate on the "namespaced_name" field.
func NamespacedNameNotIn ¶
NamespacedNameNotIn applies the NotIn predicate on the "namespaced_name" field.
func Price ¶
Price applies equality check predicate on the "price" field. It's identical to PriceEQ.
func PriceNotIn ¶
PriceNotIn applies the NotIn predicate on the "price" field.
func ScopeNotIn ¶
ScopeNotIn applies the NotIn predicate on the "scope" field.
func ScopeValidator ¶
ScopeValidator is a validator for the "scope" field enum values. It is called by the builders before save.
func SyncedAt ¶
SyncedAt applies equality check predicate on the "synced_at" field. It's identical to SyncedAtEQ.
func SyncedAtEQ ¶
SyncedAtEQ applies the EQ predicate on the "synced_at" field.
func SyncedAtGT ¶
SyncedAtGT applies the GT predicate on the "synced_at" field.
func SyncedAtGTE ¶
SyncedAtGTE applies the GTE predicate on the "synced_at" field.
func SyncedAtIn ¶
SyncedAtIn applies the In predicate on the "synced_at" field.
func SyncedAtIsNil ¶
SyncedAtIsNil applies the IsNil predicate on the "synced_at" field.
func SyncedAtLT ¶
SyncedAtLT applies the LT predicate on the "synced_at" field.
func SyncedAtLTE ¶
SyncedAtLTE applies the LTE predicate on the "synced_at" field.
func SyncedAtNEQ ¶
SyncedAtNEQ applies the NEQ predicate on the "synced_at" field.
func SyncedAtNotIn ¶
SyncedAtNotIn applies the NotIn predicate on the "synced_at" field.
func SyncedAtNotNil ¶
SyncedAtNotNil applies the NotNil predicate on the "synced_at" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpstreamID ¶
UpstreamID applies equality check predicate on the "upstream_id" field. It's identical to UpstreamIDEQ.
func UpstreamIDEQ ¶
UpstreamIDEQ applies the EQ predicate on the "upstream_id" field.
func UpstreamIDIn ¶
UpstreamIDIn applies the In predicate on the "upstream_id" field.
func UpstreamIDNEQ ¶
UpstreamIDNEQ applies the NEQ predicate on the "upstream_id" field.
func UpstreamIDNotIn ¶
UpstreamIDNotIn applies the NotIn predicate on the "upstream_id" field.
func UserID ¶
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDIsNil ¶
UserIDIsNil applies the IsNil predicate on the "user_id" field.
func UserIDNotIn ¶
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func UserIDNotNil ¶
UserIDNotNil applies the NotNil predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func VersionHash ¶
VersionHash applies equality check predicate on the "version_hash" field. It's identical to VersionHashEQ.
func VersionHashContains ¶
VersionHashContains applies the Contains predicate on the "version_hash" field.
func VersionHashContainsFold ¶
VersionHashContainsFold applies the ContainsFold predicate on the "version_hash" field.
func VersionHashEQ ¶
VersionHashEQ applies the EQ predicate on the "version_hash" field.
func VersionHashEqualFold ¶
VersionHashEqualFold applies the EqualFold predicate on the "version_hash" field.
func VersionHashGT ¶
VersionHashGT applies the GT predicate on the "version_hash" field.
func VersionHashGTE ¶
VersionHashGTE applies the GTE predicate on the "version_hash" field.
func VersionHashHasPrefix ¶
VersionHashHasPrefix applies the HasPrefix predicate on the "version_hash" field.
func VersionHashHasSuffix ¶
VersionHashHasSuffix applies the HasSuffix predicate on the "version_hash" field.
func VersionHashIn ¶
VersionHashIn applies the In predicate on the "version_hash" field.
func VersionHashIsNil ¶
VersionHashIsNil applies the IsNil predicate on the "version_hash" field.
func VersionHashLT ¶
VersionHashLT applies the LT predicate on the "version_hash" field.
func VersionHashLTE ¶
VersionHashLTE applies the LTE predicate on the "version_hash" field.
func VersionHashNEQ ¶
VersionHashNEQ applies the NEQ predicate on the "version_hash" field.
func VersionHashNotIn ¶
VersionHashNotIn applies the NotIn predicate on the "version_hash" field.
func VersionHashNotNil ¶
VersionHashNotNil applies the NotNil predicate on the "version_hash" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the MCPTool queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDescription ¶
func ByDescription(opts ...sql.OrderTermOption) OrderOption
ByDescription orders the results by the description field.
func ByEnabled ¶
func ByEnabled(opts ...sql.OrderTermOption) OrderOption
ByEnabled orders the results by the enabled field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByNamespacedName ¶
func ByNamespacedName(opts ...sql.OrderTermOption) OrderOption
ByNamespacedName orders the results by the namespaced_name field.
func ByPrice ¶
func ByPrice(opts ...sql.OrderTermOption) OrderOption
ByPrice orders the results by the price field.
func ByScope ¶
func ByScope(opts ...sql.OrderTermOption) OrderOption
ByScope orders the results by the scope field.
func BySyncedAt ¶
func BySyncedAt(opts ...sql.OrderTermOption) OrderOption
BySyncedAt orders the results by the synced_at field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpstreamField ¶
func ByUpstreamField(field string, opts ...sql.OrderTermOption) OrderOption
ByUpstreamField orders the results by upstream field.
func ByUpstreamID ¶
func ByUpstreamID(opts ...sql.OrderTermOption) OrderOption
ByUpstreamID orders the results by the upstream_id field.
func ByUserID ¶
func ByUserID(opts ...sql.OrderTermOption) OrderOption
ByUserID orders the results by the user_id field.
func ByVersionHash ¶
func ByVersionHash(opts ...sql.OrderTermOption) OrderOption
ByVersionHash orders the results by the version_hash field.