Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.MCPUserToolSetting) predicate.MCPUserToolSetting
- func CreatedAt(v time.Time) predicate.MCPUserToolSetting
- func CreatedAtEQ(v time.Time) predicate.MCPUserToolSetting
- func CreatedAtGT(v time.Time) predicate.MCPUserToolSetting
- func CreatedAtGTE(v time.Time) predicate.MCPUserToolSetting
- func CreatedAtIn(vs ...time.Time) predicate.MCPUserToolSetting
- func CreatedAtLT(v time.Time) predicate.MCPUserToolSetting
- func CreatedAtLTE(v time.Time) predicate.MCPUserToolSetting
- func CreatedAtNEQ(v time.Time) predicate.MCPUserToolSetting
- func CreatedAtNotIn(vs ...time.Time) predicate.MCPUserToolSetting
- func Enabled(v bool) predicate.MCPUserToolSetting
- func EnabledEQ(v bool) predicate.MCPUserToolSetting
- func EnabledNEQ(v bool) predicate.MCPUserToolSetting
- func ID(id uuid.UUID) predicate.MCPUserToolSetting
- func IDEQ(id uuid.UUID) predicate.MCPUserToolSetting
- func IDGT(id uuid.UUID) predicate.MCPUserToolSetting
- func IDGTE(id uuid.UUID) predicate.MCPUserToolSetting
- func IDIn(ids ...uuid.UUID) predicate.MCPUserToolSetting
- func IDLT(id uuid.UUID) predicate.MCPUserToolSetting
- func IDLTE(id uuid.UUID) predicate.MCPUserToolSetting
- func IDNEQ(id uuid.UUID) predicate.MCPUserToolSetting
- func IDNotIn(ids ...uuid.UUID) predicate.MCPUserToolSetting
- func Not(p predicate.MCPUserToolSetting) predicate.MCPUserToolSetting
- func Or(predicates ...predicate.MCPUserToolSetting) predicate.MCPUserToolSetting
- func ToolID(v uuid.UUID) predicate.MCPUserToolSetting
- func ToolIDEQ(v uuid.UUID) predicate.MCPUserToolSetting
- func ToolIDGT(v uuid.UUID) predicate.MCPUserToolSetting
- func ToolIDGTE(v uuid.UUID) predicate.MCPUserToolSetting
- func ToolIDIn(vs ...uuid.UUID) predicate.MCPUserToolSetting
- func ToolIDLT(v uuid.UUID) predicate.MCPUserToolSetting
- func ToolIDLTE(v uuid.UUID) predicate.MCPUserToolSetting
- func ToolIDNEQ(v uuid.UUID) predicate.MCPUserToolSetting
- func ToolIDNotIn(vs ...uuid.UUID) predicate.MCPUserToolSetting
- func UpdatedAt(v time.Time) predicate.MCPUserToolSetting
- func UpdatedAtEQ(v time.Time) predicate.MCPUserToolSetting
- func UpdatedAtGT(v time.Time) predicate.MCPUserToolSetting
- func UpdatedAtGTE(v time.Time) predicate.MCPUserToolSetting
- func UpdatedAtIn(vs ...time.Time) predicate.MCPUserToolSetting
- func UpdatedAtLT(v time.Time) predicate.MCPUserToolSetting
- func UpdatedAtLTE(v time.Time) predicate.MCPUserToolSetting
- func UpdatedAtNEQ(v time.Time) predicate.MCPUserToolSetting
- func UpdatedAtNotIn(vs ...time.Time) predicate.MCPUserToolSetting
- func UserID(v uuid.UUID) predicate.MCPUserToolSetting
- func UserIDEQ(v uuid.UUID) predicate.MCPUserToolSetting
- func UserIDGT(v uuid.UUID) predicate.MCPUserToolSetting
- func UserIDGTE(v uuid.UUID) predicate.MCPUserToolSetting
- func UserIDIn(vs ...uuid.UUID) predicate.MCPUserToolSetting
- func UserIDLT(v uuid.UUID) predicate.MCPUserToolSetting
- func UserIDLTE(v uuid.UUID) predicate.MCPUserToolSetting
- func UserIDNEQ(v uuid.UUID) predicate.MCPUserToolSetting
- func UserIDNotIn(vs ...uuid.UUID) predicate.MCPUserToolSetting
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByEnabled(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByToolID(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUserID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the mcpusertoolsetting type in the database. Label = "mcp_user_tool_setting" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // FieldToolID holds the string denoting the tool_id field in the database. FieldToolID = "tool_id" // FieldEnabled holds the string denoting the enabled field in the database. FieldEnabled = "enabled" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // Table holds the table name of the mcpusertoolsetting in the database. Table = "mcp_user_tool_settings" )
Variables ¶
var ( // DefaultEnabled holds the default value on creation for the "enabled" field. DefaultEnabled bool // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time )
var Columns = []string{ FieldID, FieldUserID, FieldToolID, FieldEnabled, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for mcpusertoolsetting fields.
Functions ¶
func And ¶
func And(predicates ...predicate.MCPUserToolSetting) predicate.MCPUserToolSetting
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.MCPUserToolSetting
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.MCPUserToolSetting
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.MCPUserToolSetting
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.MCPUserToolSetting
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.MCPUserToolSetting
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.MCPUserToolSetting
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.MCPUserToolSetting
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.MCPUserToolSetting
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.MCPUserToolSetting
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Enabled ¶
func Enabled(v bool) predicate.MCPUserToolSetting
Enabled applies equality check predicate on the "enabled" field. It's identical to EnabledEQ.
func EnabledEQ ¶
func EnabledEQ(v bool) predicate.MCPUserToolSetting
EnabledEQ applies the EQ predicate on the "enabled" field.
func EnabledNEQ ¶
func EnabledNEQ(v bool) predicate.MCPUserToolSetting
EnabledNEQ applies the NEQ predicate on the "enabled" field.
func ID ¶
func ID(id uuid.UUID) predicate.MCPUserToolSetting
ID filters vertices based on their ID field.
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.MCPUserToolSetting
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.MCPUserToolSetting
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.MCPUserToolSetting
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.MCPUserToolSetting
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.MCPUserToolSetting
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.MCPUserToolSetting
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.MCPUserToolSetting
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.MCPUserToolSetting
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.MCPUserToolSetting) predicate.MCPUserToolSetting
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.MCPUserToolSetting) predicate.MCPUserToolSetting
Or groups predicates with the OR operator between them.
func ToolID ¶
func ToolID(v uuid.UUID) predicate.MCPUserToolSetting
ToolID applies equality check predicate on the "tool_id" field. It's identical to ToolIDEQ.
func ToolIDEQ ¶
func ToolIDEQ(v uuid.UUID) predicate.MCPUserToolSetting
ToolIDEQ applies the EQ predicate on the "tool_id" field.
func ToolIDGT ¶
func ToolIDGT(v uuid.UUID) predicate.MCPUserToolSetting
ToolIDGT applies the GT predicate on the "tool_id" field.
func ToolIDGTE ¶
func ToolIDGTE(v uuid.UUID) predicate.MCPUserToolSetting
ToolIDGTE applies the GTE predicate on the "tool_id" field.
func ToolIDIn ¶
func ToolIDIn(vs ...uuid.UUID) predicate.MCPUserToolSetting
ToolIDIn applies the In predicate on the "tool_id" field.
func ToolIDLT ¶
func ToolIDLT(v uuid.UUID) predicate.MCPUserToolSetting
ToolIDLT applies the LT predicate on the "tool_id" field.
func ToolIDLTE ¶
func ToolIDLTE(v uuid.UUID) predicate.MCPUserToolSetting
ToolIDLTE applies the LTE predicate on the "tool_id" field.
func ToolIDNEQ ¶
func ToolIDNEQ(v uuid.UUID) predicate.MCPUserToolSetting
ToolIDNEQ applies the NEQ predicate on the "tool_id" field.
func ToolIDNotIn ¶
func ToolIDNotIn(vs ...uuid.UUID) predicate.MCPUserToolSetting
ToolIDNotIn applies the NotIn predicate on the "tool_id" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.MCPUserToolSetting
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.MCPUserToolSetting
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.MCPUserToolSetting
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.MCPUserToolSetting
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.MCPUserToolSetting
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.MCPUserToolSetting
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.MCPUserToolSetting
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.MCPUserToolSetting
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.MCPUserToolSetting
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UserID ¶
func UserID(v uuid.UUID) predicate.MCPUserToolSetting
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDEQ ¶
func UserIDEQ(v uuid.UUID) predicate.MCPUserToolSetting
UserIDEQ applies the EQ predicate on the "user_id" field.
func UserIDGT ¶
func UserIDGT(v uuid.UUID) predicate.MCPUserToolSetting
UserIDGT applies the GT predicate on the "user_id" field.
func UserIDGTE ¶
func UserIDGTE(v uuid.UUID) predicate.MCPUserToolSetting
UserIDGTE applies the GTE predicate on the "user_id" field.
func UserIDIn ¶
func UserIDIn(vs ...uuid.UUID) predicate.MCPUserToolSetting
UserIDIn applies the In predicate on the "user_id" field.
func UserIDLT ¶
func UserIDLT(v uuid.UUID) predicate.MCPUserToolSetting
UserIDLT applies the LT predicate on the "user_id" field.
func UserIDLTE ¶
func UserIDLTE(v uuid.UUID) predicate.MCPUserToolSetting
UserIDLTE applies the LTE predicate on the "user_id" field.
func UserIDNEQ ¶
func UserIDNEQ(v uuid.UUID) predicate.MCPUserToolSetting
UserIDNEQ applies the NEQ predicate on the "user_id" field.
func UserIDNotIn ¶
func UserIDNotIn(vs ...uuid.UUID) predicate.MCPUserToolSetting
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the MCPUserToolSetting queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByEnabled ¶
func ByEnabled(opts ...sql.OrderTermOption) OrderOption
ByEnabled orders the results by the enabled field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByToolID ¶
func ByToolID(opts ...sql.OrderTermOption) OrderOption
ByToolID orders the results by the tool_id field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUserID ¶
func ByUserID(opts ...sql.OrderTermOption) OrderOption
ByUserID orders the results by the user_id field.